<?php

namespace FiloBlu\Refilo\Model\Exporter;

use FiloBlu\Refilo\Model\Adapter\Mongo;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Store\Model\StoreManagerInterface;

class Menu
{
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var Mongo
     */
    private $mongo;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    /**
     * Menu constructor.
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     * @param Mongo $mongo
     * @param StoreManagerInterface $storeManager
     */
    public function __construct(
        ResourceConnection $resourceConnection,
        ScopeConfigInterface $scopeConfig,
        Mongo $mongo,
        StoreManagerInterface $storeManager
    ) {
        $this->resourceConnection = $resourceConnection;
        $this->scopeConfig = $scopeConfig;
        $this->mongo = $mongo;
        $this->storeManager = $storeManager;
    }

    public function exportMenu()
    {
        $this->mongo->dropCollection("menus", $this->scopeConfig->getValue('mongo/general/mongo_general_database'));
        $bulkData = [];
        $_id = 1;
        foreach ($this->storeManager->getStores() as $key => $value) {
            $query = "SELECT bmn.*,bmm.title as menu_title, bmm.identifier as code FROM blackbird_menumanager_node as bmn
                                inner join blackbird_menumanager_menu as bmm on bmm.menu_id=bmn.menu_id
                                inner join blackbird_menumanager_store as bms on bms.menu_id=bmm.menu_id and (store_id = " . $value->getData('store_id') . " or store_id = 0)
                                where bmn.is_active = 1";

            $result = $this->resourceConnection->getConnection()->fetchAll($query);
            foreach ($result as $item) {
                $menu = new \stdClass();

                $menu->_id = $_id;
                $menu->node_id = $item['node_id'];
                $menu->code = $item['code'];
                $menu->type = $item['type'];
                $menu->object_id = $item['entity_id'];
                $menu->parent_id = $item['parent_id'];
                $menu->position = $item['position'];
                $menu->level = $item['level'];
                $menu->title = $item['title'];
                $menu->menu_title = $item['menu_title'];
                $menu->target = $item['target'];
                $menu->url = $item['url_path'];
                $menu->store = $value->getData('code');

                $bulkData[] = $menu;
                $_id++;
            }
        }

        try {
            $this->mongo->update(
                '_id',
                $bulkData,
                'menus',
                true,
                $this->scopeConfig->getValue('mongo/general/mongo_general_database')
            );
        } catch (MongoDB\Driver\Exception\Exception $e) {
            echo $e->getMessage();
        }
    }
}
