<?php

namespace FiloBlu\Refilo\Setup;

use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\UpgradeDataInterface;
use Zend_Locale;

class UpgradeData implements UpgradeDataInterface
{

    public function upgrade(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;

        $installer->getConnection()->startSetup();
        if (version_compare($context->getVersion(), '1.0.1', '<')) {
            $this->upgradeGeoData($installer);
            $this->upgradeCountryTranslations($installer);
        }
        $installer->getConnection()->endSetup();
    }

    public function upgradeGeoData(ModuleDataSetupInterface $installer)
    {

        $countryContinentTableName = $installer->getTable('filoblu_refilo_country_continent');
        $continentTableName = $installer->getTable('filoblu_refilo_continent');

        $countryContinentData = json_decode(file_get_contents($this->getFilePath('country_continent.json')), true);
        $continentData = json_decode(file_get_contents($this->getFilePath('continent.json')), true);

        foreach ($countryContinentData as $item) {
            $installer->getConnection()->insert($countryContinentTableName, $item);
        }

        foreach ($continentData as $item) {
            $installer->getConnection()->insert($continentTableName, $item);
        }
    }

    /**
     * @param $filename
     * @return string
     */
    public function getFilePath($filename)
    {
        return implode(
            DIRECTORY_SEPARATOR,
            [__DIR__, '..', 'Files', $filename]
        );
    }

    public function upgradeCountryTranslations(ModuleDataSetupInterface $installer)
    {

        $translationTable = $installer->getTable('translation');


        $localeList = ['en_US', 'it_IT', 'fr_FR', 'de_DE', 'es_ES', 'zh_CN','ru_RU','ja_JP'];

        foreach ($localeList as $locale) {
            $list = Zend_Locale::getTranslationList('territory', $locale, 2);
            foreach ($list as $countryCode => $translation) {
                $item = [
                    "string" => "country_" . $countryCode,
                    "store_id" => 0,
                    "translate" => $translation,
                    "locale" => $locale
                ];
                $installer->getConnection()->insert($translationTable, $item);
            }
        }
    }
}
